%
%
% Un-damped dynamic analysis of the Bergsysund floating bridge
%
%
%
%

ndofsup = 150;
ndofpc  = 36;
ndofG   = 360;
npc     = 7;
L       = 840;
dx      = L/24;
Bp      = 20;
g       = 9.81;
d       = 4.4675;
Lp      = 30;

w = 3.642;
Cyy = 0.1;
Czz = 0.1;
Crr = 0.1;
Cxx = 0.1;

[mzz,Mzz] = Bergsoy_interpolation_added_mass_heave(w,Bp,g,d);
[mrr,Mrr] = Bergsoy_interpolation_added_mass_roll(w,Bp,g,d);
[mxx,Mxx] = Bergsoy_interpolation_added_mass_surge(w,Lp,g,d);
[myy,Myy] = Bergsoy_interpolation_added_mass_sway(w,Bp,g,d);





% Importing global property matrices

[MG,CG,KG] = Bergsoy_G_global_property_matrices(ndofsup,ndofpc,ndofG,npc,Myy,Mzz,Mrr,Mxx,Cyy,Czz,Crr,Cxx);


% Defining boundary conditions of the system

k = [1 2 3 4 5 356 357 358 359]; 

   MGred = MG;
   KGred = KG;
   

   MGred(k,:) = [];
   MGred(:,k) = [];

   KGred(k,:) = [];
   KGred(:,k) = [];
    


% Establishing an Eigen value problem

[V,D] = eig(KGred,MGred);

w = sqrt(diag(D));
[om,ix] = sort(w);


% Numbering of the DOF's along the bridge span when the boundary conditions
% of the floating bridge model are introduced.

nroll  = [5 11 17 53 59 65 101 107 113 149 155 161 197 203 209 245 251 257 293 299 305 341 347];
nheave = [4 10 16 52 58 64 100 106 112 148 154 160 196 202 208 244 250 256 292 298 304 340 346];
nsway  = [3  9 15 51 57 63  99 105 111 147 153 159 195 201 207 243 249 255 291 297 303 339 345];


% Writing a vector for the heave displacements along the bridge span,
% further expanding the vector to include the zero displacements at the
% ends.

nat = 1;            % Natural frequency of mode shape number

Dr1 = V(nroll,ix(nat));
Dh1 = V(nheave,ix(nat));
Ds1 = V(nsway,ix(nat));



Dr1exp = zeros(1,length(Dr1)+2);
Dh1exp = zeros(1,length(Dh1)+2);
Ds1exp = zeros(1,length(Ds1)+2);


for i = 1:length(Dr1);
    
    Dr1exp(i+1) = Dr1(i);
    Dh1exp(i+1) = Dh1(i);
    Ds1exp(i+1) = Ds1(i);
    
end


x = zeros(1,length(Dr1exp));     % Posistion vector along the bridge span

for i = 1:length(Dr1exp);
    
    x(i) = (i-1)*dx;
    
end


% Plot of mode shapes

figure(1);
plot(x,Ds1exp,'b',x,Dh1exp,'r',x,Dr1exp,'g');
title(['Mode Shape for Natural Frequency No.',num2str(nat),'   w = ',num2str(om(nat)),'  [rad/s] ']);
xlabel('Length of bridge   L = 840m');
legend('Sway','Heave','Roll');




