function [asupG,apcG] = Bergsoy_G_connectivity_low_bandwidth(ndofsup,ndofpc,npc,ndofG)
%
%
% Development of a set of alternative connectivity matrices to obtain more 
% narrow banded property matrices, and in turn obtain better scaling of the
% property matrices.
%
% The global numbering of the nodes are done consistent as moving from one
% side of the bridge span towards the other, including the DOF's of the
% pontoons as they are encountered. By this proceedure, the bandwidth of 
% the property matrices should be limited to a maximum of 6 nodes (36DOF's)
% For the original connectivity matrices, the bridge superstructure was
% modelled first, and the consecutive pontoon sub-systems where included at
% the end. Resulting in a maximum bandwidth of 216 nodes (1296 DOF's).
%
%
%
% By Axel Wullf Wathne, 2012.
%



% Number of DOF's associated with each node

Nodedof = 6;

% Connectivity matrix for linking the DOF's of the bridge superstructure 
% sub-system to the DOF's of the global model. 

asupG = zeros(ndofsup,ndofG);


for i = 1:4*Nodedof;    % Loop over the DOF's of the first four nodes of 
                        % the SUP-sub-system.
    
    asupG(i,i) = 1;
    
end

for i = 1:3*Nodedof;    % Loop over DOF's of three nodes for the rest of 
                        % bridge spans between each pontoon connection.
    
    asupG(24+i , 54 +i) = 1;
    asupG(42+i , 102+i) = 1;
    asupG(60+i , 150+i) = 1;
    asupG(78+i , 198+i) = 1;
    asupG(96+i , 246+i) = 1;
    asupG(114+i, 294+i) = 1;
    asupG(132+i, 342+i) = 1;
    
end



% Connectivity matrices for the pontoon-connector sub-systems

apcG = zeros(ndofpc,ndofG,npc);
    
    
for j = 0:npc-1;        % Loop over the number of pontoon sub-systems to 
                        % allocate the DOF's of the connection points
                        % between the pc-sub-systems and the bridge span.
    
    for k = 1:ndofpc;  % Loop over the DOF's of the pc-sub-systems                    
    
        apcG(k, 18+(j*48)+k, j+1) = 1;
        
        
%         apcG(k,  66+k, 2) = 1;
%         apcG(k, 114+k, 3) = 1;
%         apcG(k, 162+k, 4) = 1;
%         apcG(k, 210+k, 5) = 1;
%         apcG(k, 258+k, 6) = 1;
%         apcG(k, 306+k, 7) = 1;
        
    end
    
end


end        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
        
    