function [asupG,apcG] = Bergsoy_G_connectivity_matrices_global_assembly(ndofsup,ndofpc,ndofG,npc)
%
%
% Connectivity matrices for the assembly of the 3D model of Bergsysund
% floating bridge with 24 elements along the superstructure and 7
% pontoon-connector sub-systems introduced in the model, each consisting of
% 5 elements.
%
%
% The total 3D floating bridge model consist of ndofG=360 global DOF's. The
% bridge superstructure sub-system has ndofsup=150 DOF's which are
% transformed to the global coordinate system. Each pontoon-connector
% sub-system has ndofpc=36 DOF's which also are oriented in the global
% coordinate system. The fact that the DOF's of the sub-systems that make
% up the model are transformed to the global coordinate system, makes the
% establishing of the connectivity matrices more favourable. All DOF's of
% the sub-systems have a one-to-one relation to the global DOF's, and the
% numbering of the DOF's at each node is done in the same fashion.
%
% The connectivity matrix linking the DOF's of the superstructure
% sub-system to the global DOF's has dimension [150 x 360].
% The connectivity matrices linking the DOF's of the pontoon-connector
% sub-system to the global DOF's have dimensions [36 x 360]
%
%
% Input: ndofsup - number of DOF's for the superstructure sub-system
%        ndofpc  - number of DOF's for the PC-sub-system
%        ndofG   - number of global DOF's for the full model
%        npc     - number of PC-sub-systems introduced in the model
%
%
% By Axel Wullf Wathne, 2012.
%



% Connectivity matrix for the superstructure sub-system

asupG = zeros(ndofsup,ndofG);

for i = 1:ndofsup;      % Loop over the superstructure sub-system DOF's
    
    asupG(i,i) = 1;
    
end

% Connectivity matrices for the pontoon-connector sub-systems

apcG = zeros(ndofpc,ndofG,npc);

    
for m = 1:npc;      % Loop over all PC-sub-systems.
    for i = 1:6;    % Loop over the six first DOF's of each sub-system. 
                    % These are connected to the bridge superstructure.
    
                    
    apcG(i , i+(18*m), m) = 1;   % Connecting the DOF's assosiated with the
                                 % first node of each pc-sub-system to the
                                 % global DOF's.
    
    end




    for j = 7:36;   % Loop over the final 30 DOF's of each sub-system. 
                    % These are assosiated with the pontoons and are
                    % numbered consistent with the global DOF's.    
    
                   
                    
    apcG(j , j+(114+(30*m)), m) = 1;    % Connecting the DOF's assosiated with the
                                        % nodes 2-6 of each pc-sub-system
                                        % to the global DOF's.
    end
    
end

end
    
    
    
    
    
    
    
    
    
    
    