%
%
% Simplifyed modelling of a Response spectrum
%
% By Axel W. Wathne, 2012
% 

ndofG    = 360;
ndofGred = ndofG - 9;

% Defining frequency range

dw   = 0.5;
wmax = 5;
Nw   = fix(wmax/dw);

w    = (1:Nw)*dw;


% Defining a sea state 1

omega0 = 0;
s      = 3;
Hs     = 1;
Tp     = 3;

% Importing JONSWAP values for the frequencies for Tp

[Sf] = JONSWAP_spectrum_Hz(Hs,Tp,w);


% Importing load spectrum for the bridge for s

[RG,SR] = Bergsoy_load_spectrum2(Nw,dw,omega0,s);


% Importing H-matrix

[H] = Bergsoy_H_matrix(dw,Nw);


% Introducing the boundary conditions of the model

k = [1 2 3 4 5 356 357 358 359]; 
 
   SRred  = SR;
   Hred   = H;
   

   SRred(k,:,:) = [];
   SRred(:,k,:) = [];

   Hred(k,:,:)  = [];
   Hred(:,k,:)  = [];


% Determination of transfer function for the fluid-structure system

Tfunc = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;

Tfunc(:,:,i) = Hred(:,:,i)*SRred(:,:,i)*ctranspose(Hred(:,:,i));

end


% Determination of response spectrum


Sr1 = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;
    
    Sr1(:,:,i) = Tfunc(:,:,i).*Sf(i);
    
end


% Second response spectrum for different sea state

% Defining a sea state 2

omega0 = 0;
s      = 15;
Hs     = 1;
Tp     = 10;

% Importing JONSWAP values for the frequencies for Tp

[Sf] = JONSWAP_spectrum_Hz(Hs,Tp,w);


% Importing load spectrum for the bridge for s

[RG,SR] = Bergsoy_load_spectrum2(Nw,dw,omega0,s);

% Introducing the boundary conditions of the model

k = [1 2 3 4 5 356 357 358 359]; 
 
   SRred  = SR;
  
   SRred(k,:,:) = [];
   SRred(:,k,:) = [];
   
   
% Determination of transfer function for the fluid-structure system

Tfunc = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;

Tfunc(:,:,i) = Hred(:,:,i)*SRred(:,:,i)*ctranspose(Hred(:,:,i));

end


% Determination of response spectrum


Sr2 = zeros(ndofGred,ndofGred,Nw);

for i = 1:Nw;
    
    Sr2(:,:,i) = Tfunc(:,:,i).*Sf(i);
    
end
   

% Determination of a total response spectrum as the sum of the response
% spectrums from the two sea states

Sr = Sr1 + Sr2;


% Writing a frequency reponse vector of the response

h160 = zeros(1,Nw);     % Response vector for DOf 165
h178 = zeros(1,Nw);     % Response vector for DOF 183
h64  = zeros(1,Nw);     % Auto-specter for DOF 69


for i=1:Nw;
    
    
    h160(i) = Sr(160,160,i);
    h178(i) = Sr(178,178,i);
    h64(i)  = Sr(64,64,i);
    
    
end


figure(1)
plot(w,h160,'b',w,h178,'r',w,h64,'g');
title('Heave Response Auto Spectrum');
xlabel('Frequency  [rad/s]');
legend('Heave Mid-Point','Heave Mid-Point Centre Pontoon','Heave L/4-Point');





% Extreme values

% Time intervall for evaluation of response parameters

T = 7200;       % 7200 sec = 2 hour


% Peak factor for evaluation of extreme values

kp = 1;


% Variance of the heave response

varh178 = trapz(w,h178);
varh160 = trapz(w,h160);
varh64  = trapz(w,h64);

% Standard deviation of the heave response

stdh178 = sqrt(varh178);
stdh160 = sqrt(varh160);
stdh64  = sqrt(varh64);

% Defining the 0'th, 2'nd and 4'th spectral moments

m0178 = zeros(1,Nw);
m2178 = zeros(1,Nw);
m4178 = zeros(1,Nw);

m0160 = zeros(1,Nw);
m2160 = zeros(1,Nw);
m4160 = zeros(1,Nw);

m064  = zeros(1,Nw);
m264  = zeros(1,Nw);
m464  = zeros(1,Nw);


for i = 1:Nw;
    
    m0178(i) = h178(i);
    m2178(i) = w(i)^2*h178(i);
    m4178(i) = w(i)^2*h178(i);
    
    m0160(i) = h160(i);
    m2160(i) = w(i)^2*h160(i);
    m4160(i) = w(i)^2*h160(i);
    
    m064(i) = h64(i);
    m264(i) = w(i)^2*h64(i);
    m464(i) = w(i)^2*h64(i);
    
end

ms0178 = trapz(w,m0178);
ms2178 = trapz(w,m2178);
ms4178 = trapz(w,m4178);

ms0160 = trapz(w,m0160);
ms2160 = trapz(w,m2160);
ms4160 = trapz(w,m4160);

ms064  = trapz(w,m064);
ms264  = trapz(w,m264);
ms464  = trapz(w,m464);


% Determining the rms bandwidth of the process

e178 = sqrt(1 - ((ms2178^2)/(ms0178*ms4178)));
e160 = sqrt(1 - ((ms2160^2)/(ms0160*ms4160)));
e64  = sqrt(1 - ((ms264^2)/(ms064*ms464)));


% Determining the zero crossing period

Tz178 = 2*pi*sqrt(ms0178/ms2178);
Tz160 = 2*pi*sqrt(ms0160/ms2160);
Tz64  = 2*pi*sqrt(ms064/ms264);


% Estimation of the largest expected maximum within time intervall T

Ermax178 = stdh178*(sqrt(2*log(T/Tz178)) + 0.5772/(sqrt(2*log(T/Tz178))));
Ermax160 = stdh160*(sqrt(2*log(T/Tz160)) + 0.5772/(sqrt(2*log(T/Tz160))));
Ermax64  = stdh64*(sqrt(2*log(T/Tz64)) + 0.5772/(sqrt(2*log(T/Tz64))));

% Standard deviation corresponding to the expected largest maximum

stdrmax178 = ((stdh178*pi)/sqrt(6))*(1/(sqrt(2*log(T/Tz178))));
stdrmax160 = ((stdh160*pi)/sqrt(6))*(1/(sqrt(2*log(T/Tz160))));
stdrmax64  = ((stdh64*pi)/sqrt(6))*(1/(sqrt(2*log(T/Tz64))));


% Maximum response in heave at mid-node within a desired number of standard
% deviations may be determined. The peak factor, kp, is set at the number
% of standard deviations to include. kp=1 thus corresponds to one standard
% deviation.

rmax178 = abs(Ermax178) + kp*abs(stdrmax178);

rmax160 = abs(Ermax160) + kp*abs(stdrmax160);

rmax64  = abs(Ermax64) + kp*abs(stdrmax64);










