function [Wamp] = Bergsoy_Waveamp(dw,Nw)

%
%Wave amplifyer for each element
%




s   = 5;        % Spreading index
g   = 9.81;     % Gravitational contant
om0 = 0;        % Mean angle of wave approach
a   = 1;        % Wave amplitude
Lpe = 7.5;      % Length of pontoon elements
npc = 7;        % Number of pontoons
nel = 4;        % number of elements per pontoons


% Defining the arch shape as function of the x-position of each node.

R    = 1300;   % Radius of the horizontal arch.
Nsup = 25;     % Nodes along the bridge span.
L    = 840;    % Length of bridge in x-direction

% Arch height at mid-point, deltamid.

hmid     = sqrt(R^2 - (L/2)^2);
deltamid = R - hmid;

% Vectors for the x- and y-postion of the nodes along the bridge
% superstructure.

x = (-L/2: L/(Nsup-1) : L/2);

y = zeros(1,length(x));

deltay = zeros(1,length(x));


% Postion of each node in the y-plane corresponding with x-position

for i = 1:length(x);

y(i) = sqrt(R^2 - x(i)^2);    % Function for a circle, defining the y-position 
                              % according to x-postion.
                        
deltay(i) = y(i) - hmid;      % The postion above the x-axis in the y-direction 
                              % of node i along the bridge span.

end

% Defining the positions of connection points between the arch bridge span 
% and the pontoons in space.

xpos = [x(4) x(7) x(10) x(13) x(16) x(19) x(22)];
ypos = [deltay(4) deltay(7) deltay(10) deltay(13) deltay(16) deltay(19) deltay(22)];



% Defining the orientation of each element in space (dx, dy and Le)

dx = L/(Nsup-1);        % Lenght of each element in the x-direction.
dy = zeros(Nsup-1,1);   % Vector for the dy lengths of the elements.
Le = zeros(Nsup-1,1);   % Vector for the total lengths of the elements.
xx = zeros(Nsup-1,1);   % Vector for storing element angles


for i = 1:Nsup-1;       % Loop over the arch elements

dy(i) = deltay(i+1) - deltay(i);      % Length of element i in y-direction.

Le(i) = sqrt(dx*dx + dy(i)*dy(i));    % Total length of element i.


xx(i) = atan(dy(i)/dx);

end

% Vector for the average angle of the arch at the positions of pontoon
% connection relative to the x-axis. These angles are identical to the
% pontoon local x-axis relative to the global y-axis.


xxavg = [xx(3)+xx(4) xx(6)+xx(7) xx(9)+xx(10) xx(12)+xx(13) xx(15)+xx(16) xx(18)+xx(19) xx(21)+xx(22)]*0.5;    


% Positions of each element

xe = zeros(4,7);
ye = zeros(4,7);

for j = 1:npc;

xe(1,j) = xpos(j) + ((3*Lpe)/2)*sin(xxavg(j));
xe(2,j) = xpos(j) + (Lpe/2)*sin(xxavg(j));
xe(3,j) = xpos(j) - (Lpe/2)*sin(xxavg(j));
xe(4,j) = xpos(j) - ((3*Lpe)/2)*sin(xxavg(j));

ye(1,j) = ypos(j) - ((3*Lpe)/2)*cos(xxavg(j));
ye(2,j) = ypos(j) - (Lpe/2)*cos(xxavg(j));
ye(3,j) = ypos(j) + (Lpe/2)*cos(xxavg(j));
ye(4,j) = ypos(j) + ((3*Lpe)/2)*cos(xxavg(j));

end


Wamp = zeros(nel,npc,Nw);

w = zeros(1,Nw);

for i = 1:Nw;
    
    w(i) = i*dw;
    
    k = (w(i)^2)/g;
    
    for j = 1:npc;      % Loop over pontoons
        for p = 1:nel;    % Loop over pontoon elements
    

Wamp(p,j,i) = a*sin(-k*((xe(p,j)*sin(om0))+(ye(p,j)*cos(om0))));

        end
    end
end


end


    
    
    
    
    
    
    
    
    
    
