function [ahydro] = Bergsoy_connectivity_hydro_transfer(Ndofel,Nel,npc,ndofG)

%
% Connectivity matrices to link the vertical translational DOF's of the
% pontoon elements to the global DOF's.
%
% A beam element is considered to have 4 DOF's describing the vertical
% displacement. These are the two vertical translational DOF's and the two
% rotational DOF's in the vertical plane.
%
% Input: ndofel - number of DOF's per element (12)
%           Nel - number of elements (28)
%         ndofG - number of global DOF's for the model
%
%
% By Axel Wullf Wathne, 2012.
%
%


% Matrix array for storing the connectivity matrices

ahydro = zeros(Ndofel,ndofG,Nel);


% The element DOF's associated with vertical displacement are 3,6,9&12.
    
    

for j = 0:npc-1;    % Loop over the the pontoon sub-systems
        
        ahydro(3,  27 + (48*j) ,(j*4)+1) = 1;
        ahydro(6,  30 + (48*j) ,(j*4)+1) = 1;
        ahydro(9,  33 + (48*j) ,(j*4)+1) = 1;
        ahydro(12, 36 + (48*j) ,(j*4)+1) = 1;
        
        ahydro(3,  33 + (48*j) ,(j*4)+2) = 1;
        ahydro(6,  36 + (48*j) ,(j*4)+2) = 1;
        ahydro(9,  39 + (48*j) ,(j*4)+2) = 1;
        ahydro(12, 42 + (48*j) ,(j*4)+2) = 1;
        
        ahydro(3,  39 + (48*j) ,(j*4)+3) = 1;
        ahydro(6,  42 + (48*j) ,(j*4)+3) = 1;
        ahydro(9,  45 + (48*j) ,(j*4)+3) = 1;
        ahydro(12, 48 + (48*j) ,(j*4)+3) = 1;

        ahydro(3,  45 + (48*j) ,(j*4)+4) = 1;
        ahydro(6,  48 + (48*j) ,(j*4)+4) = 1;
        ahydro(9,  51 + (48*j) ,(j*4)+4) = 1;
        ahydro(12, 54 + (48*j) ,(j*4)+4) = 1;
        
end


end






