function [cxx,Cxx] = Bergsoy_interpolation_hydro_damping_surge(w,Lp,g,d)

% Interpolation function to determine the dimensionless hydrodynamic
% damping assosiated with horisontal, surge, motion of a pontoon in the
% longitudinal direction. The hydrodynamic coefficients for sway motion of
% a rectangular object is applied, using the pontoon length instead of the
% pontoon width. The dimensional hydrodynamic damping is thus per unit
% width of the pontoons.
%
% The values for the hydrodynamic damping coefficents are interpolated
% between to vectors. One containting dimensionless angular frequency,
% w(dimless) = w^2*B/2*g. The other containing the corresponding values for
% the dimensionless damping in sway motion.
%
% 
%           w = Vector of input angular frequencies
%           k = Counting index for loop over all the input frequencies
%           d = draft of pontoon
%       wnorm = Vector of dimensionless angular frequency
%    lambda22 = Vector of hydrodynamic damping coefficients for sway motion
%  lambdasurge = Output dimensionless hydrodynamic damping coefficents for
%               surge motion. Calculated for each frequency step, k.
%
%
%
% By Axel W. Wathne, 2012.
%


rhow = 1025;

cxx = zeros(1,length(w));
Cxx = zeros(1,length(w));


for k=1:length(w);
    

    w1normi(k) = (w(k)^2*Lp)/(2*g);    %Normalised angular frequency input

if w1normi(k)<0 
        disp('Angular frequency w1 is too low');
    elseif w1normi(k)>2.5
        cxx(k) = 0.1;
    else
        

%Vectors of normalised angular frequency and corresponding dimensionless
%hydrodynamic added mass coeafficients.

wnorm = [0.00 0.125 0.25 0.375 0.50 0.625 0.75 0.875 1.00 1.125 1.25 1.375 1.50 1.625 1.75 1.875 2.00]; 
                                                                  
cyvalues  =  [0 0 0 0.025 0.0875 0.225 0.4 0.5875 0.65 0.6875 0.6375 0.6125 0.5625 0.5 0.4625 0.425 0.35];


cxx(k) = interp1(wnorm,cyvalues,w1normi(k),'spline');

end

Cxx(k) = rhow*Lp*d*cxx(k)/(sqrt(Lp/(2*g)));

end

end