%function [RG] = Bergsoy_load_vector(Nw,wh)
%
%
% Load vector for pontoon elements
%
%
%

dw=0.1;
wmax=5;
Nw=fix(wmax/dw);

w = (1:Nw)*dw;

rhow = 1025;
Bp   = 20;
g    = 9.81;
Lp   = 30;
Lep  = Lp/4;

% Importing element positions

[xe,ye] = Bergsoy_pc_element_position;


% Wave spatial amplifyer

[Wampcos] = Surface_elevation(xe,ye,w);


npc   = 7;
nel   = 4;
Nel   = 28;
ndofz = 4;
ndofG = 360;


% Total heave load per unit length for each element as a function of their 
% position in space. rhow*g*Bp is the maximum heave loading on an element
% and Wampcos scales the loading according to position.


qh = zeros(nel,npc,Nw);
%w = zeros(Nw);

for i = 1:Nw;
    
    %w(i) = dw*i;
    
    for j = 1:npc;
        for p = 1:nel;
        
        
        qh(p,j,i) = rhow*g*Bp*Wampcos(p,j,i);
        
        end
    end
end


% Extracting frequency dependent load amplitude for heave

[q0h,q0hdim,wdim] = floating_bridge_3D_load_amplitude_heave(Bp,w);



% Scaling the load per unit length additionally with the dimensionless
% frequency dependent load transfer function

qhscale = zeros(nel,npc,Nw);

for i = 1:Nw;
    
    qhscale(:,:,i) = qh(:,:,i).*q0hdim(i);
    
end


% Load in each element DOF

Rel = zeros(ndofz,nel,npc,Nw);

for i = 1:Nw;
    for j = 1:npc;
        for p = 1:nel; 


Rel(:,p,j,i) = qhscale(p,j,i).*[Lep/2;(Lep^2)/12;Lep/2;-(Lep^2)/2];

        end
    end
end


% Connectivity heave DOF

[aheave] = Bergsoy_con_heave_element;


% Assembly of global load vector for each frequency step

RG1 = zeros(ndofG,Nw);
RG2 = zeros(ndofG,Nw);
RG3 = zeros(ndofG,Nw);
RG4 = zeros(ndofG,Nw);
RG5 = zeros(ndofG,Nw);
RG6 = zeros(ndofG,Nw);
RG7 = zeros(ndofG,Nw);



for i = 1:Nw;

    for p = 1:nel;

RG1(:,i) = RG1(:,i) + aheave(:,:,p)'*Rel(:,p,1,i);
RG2(:,i) = RG2(:,i) + aheave(:,:,p+4)'*Rel(:,p,2,i);
RG3(:,i) = RG3(:,i) + aheave(:,:,p+8)'*Rel(:,p,3,i);
RG4(:,i) = RG4(:,i) + aheave(:,:,p+12)'*Rel(:,p,4,i);
RG5(:,i) = RG5(:,i) + aheave(:,:,p+16)'*Rel(:,p,5,i);
RG6(:,i) = RG6(:,i) + aheave(:,:,p+20)'*Rel(:,p,6,i);
RG7(:,i) = RG7(:,i) + aheave(:,:,p+24)'*Rel(:,p,7,i);

    end
end

RG = zeros(ndofG,Nw);

for i = 1:Nw;
    
    RG(:,i) = RG1(:,i)+RG2(:,i)+RG3(:,i)+RG4(:,i)+RG5(:,i)+RG6(:,i)+RG7(:,i);
end


% Load spectrum

SR = zeros(ndofG,ndofG,Nw);

for i = 1:Nw;
    for m = 1:ndofG;
        for n = 1:ndofG;
        
        SR(m,n,i) = RG(m,i)*RG(n,i);
        
        end
    end
end




%end




