%
% Development of load vector for the Bergsoysund floating bridge model.
%
% The load vector in heave is determined for each element DOF's associated
% with heave motion.
%
%
%



omega0 = 0;     % Mean angle of wave approach
s      = 5;     % Spreading index

g      = 9.81;
rhow   = 1025;

% Defining frequency range
dw   = 0.25;
wmax = 5;
Nw   = fix(wmax/dw);


w = (1:Nw)*dw;


nel   = 4;        % Number of elements modelling one pontoon
npc   = 7;        % Number of pontoons
Lep   = 7.5;      % pontoon element length
Bp    = 20;       % pontoon element width
Nel   = 28;       % Number of elements
ndofG = 360;      % Global DOF's

k = (w.^2)/g;


% Importing element positions

[xe,ye,angle] = Bergsoy_pc_element_node_position;
  

% Defining wave angle of approach

nom = 0.1;      % Angle step

omega = -pi/2 : nom*pi : pi/2;

[Direc, Ns, SumDirec, Omega] = cos_directional_spreading_function(nom,omega0,s);

%fspread = (cos(omega(a))^(2*s))

% Sea surface

Rel = zeros(nel,Nel,length(w));

%Wampsin = zeros(length(y),length(x),length(w));

Rampcospos = zeros(nel,length(omega));

% Integration over element length

Le = 0:0.1:Lep;

Rampel = zeros(nel,length(Le));

% Defining the heave loading as function of frequency

[q0h,q0hdim,wdim] = floating_bridge_3D_load_amplitude_heave(Bp,w);

q0 = rhow*g*Bp;     % Maximum heave load per unit length



for i=1:length(w);              % Loop frequency range
    for m = 1:Nel;              % Loop elements at single pontoon
    for a = 1:length(omega);    % Loop wave angle of approach domain
        for l = 1:length(Le);
            
            Rampel(1,l) = q0*q0hdim(i)*(1-((3*(Le(l)^2)/Lep^2)+(2*(Le(l)^3)/Lep^3)))*Ns*(cos(omega(a)-omega0)^(2*s))*(exp(sqrt(-1)*k(i)*(((xe(m)-(Le(l)*sin(angle(m))))*sin(omega(a)-omega0)) + ((ye(m)+Le(l)*cos(angle(m)))*cos(omega(a)-omega0))))); 
            
            Rampel(2,l) = q0*q0hdim(i)*(Le(l)-((2*(Le(l)^2)/Lep)+((Le(l)^3)/Lep^2)))*Ns*(cos(omega(a)-omega0)^(2*s))*(exp(sqrt(-1)*k(i)*(((xe(m)-(Le(l)*sin(angle(m))))*sin(omega(a)-omega0)) + ((ye(m)+Le(l)*cos(angle(m)))*cos(omega(a)-omega0)))));
            
            Rampel(3,l) = q0*q0hdim(i)*(((3*(Le(l)^2)/Lep^2)-(2*(Le(l)^3)/Lep^3)))*Ns*(cos(omega(a)-omega0)^(2*s))*(exp(sqrt(-1)*k(i)*(((xe(m)-(Le(l)*sin(angle(m))))*sin(omega(a)-omega0)) + ((ye(m)+Le(l)*cos(angle(m)))*cos(omega(a)-omega0))))); 
            
            Rampel(4,l) = q0*q0hdim(i)*((-(Le(l)^2)/Lep)+((Le(l)^3)/Lep^2))*Ns*(cos(omega(a)-omega0)^(2*s))*(exp(sqrt(-1)*k(i)*(((xe(m)-(Le(l)*sin(angle(m))))*sin(omega(a)-omega0)) + ((ye(m)+Le(l)*cos(angle(m)))*cos(omega(a)-omega0)))));
            
        end
        
        for n = 1:nel;
            
        Rampcospos(n,a) = trapz(Le,Rampel(n,:)); 
        
        end
    
    end
    
    for n = 1:nel;
    
    Rel(n,m,i) = (trapz(omega,Rampcospos(n,:)));
    
    end

    
    end

end


% The Rel matrix array stores the element load vectors at each frequency
% step. Rel(:,m,i) is the [1x4]-load vector for element m at frequency step i


% Assembly of load vector array at each frequency step


% Connectivity heave DOF

[aheave] = Bergsoy_con_heave_element;


% Assembly of global load vector for each frequency step

RG = zeros(ndofG,Nw);

for i = 1:Nw;

    for j = 1:Nel;

RG(:,i) = RG(:,i) + aheave(:,:,j)'*Rel(:,j,i);


    end
end



% Load spectrum

SR = zeros(ndofG,ndofG,Nw);

for i = 1:Nw;
    for m = 1:ndofG;
        for n = 1:ndofG;
        
        SR(m,n,i) = RG(m,i)*conj(RG(n,i));
        
        end
    end
end








