function [apc] = Bergsoy_pc_connectivity_matrices(ndofel,ndofpc,Npc)

% Function that stores the connectivity matrices for the five element 
% pontoon-connector sub-system, for a 3D model of the Bergsysund floating
% bridge.
%
% The connectivity matrices relate the element DOF's to the DOF's of the
% pontoon-connector sub-system developed to represent one pontoon
% construction with connector to be connected to the superstructure of a
% floating bridge.
%
% Input: ndofel - number of DOF's for a 3D-12DOF element
%        ndofpc - number of DOF's for the pc-sub-system (36 - 6 nodes)
%           Npc - number of nodal point for the 5 element pc-sub-system  
%
%
%



% Assembly of sub-system stiffness matrix

% Establishing the connectivity matrices

apc = zeros(ndofel,ndofpc,Npc-1);  % Constructing three connectivity matrices of 
                                   % size [12 x 36], which are stored in a matrix
                                   % array. Such that connectivity matrix a(:,:,1)
                                   % corresponds to the connectivity matrix of the
                                   % first element DOF's to the sub-sytem DOF's.
                                   % a(:,:,2) to the second, and so on..
                         
% Connectivity matrix input from modelling

% The element DOF's are denoted as r(ndofel), while the sub-system DOF's
% are referred to as d(ndof).

% For the connectivity matrix a1 [a(:,:,1)]

% Node 1 for element 1
apc(1,3,1) = -1;  % Links r1 = -d3
apc(2,2,1) =  1;  % Links r2 =  d2
apc(3,1,1) =  1;  % Links r3 =  d1
apc(4,5,1) = -1;  % Links r4 = -d5
apc(5,4,1) =  1;  % Links r5 =  d4
apc(6,6,1) =  1;  % Links r6 =  d6

% Node 2 for element 1
apc(7,21,1)  = -1;  % Links r7  = -d21
apc(8,20,1)  =  1;  % Links r8  =  d20
apc(9,19,1)  =  1;  % Links r9  =  d19
apc(10,23,1) = -1;  % Links r10 = -d23
apc(11,22,1) =  1;  % Links r11 =  d22
apc(12,24,1) =  1;  % Links r12 =  d24



% For the connectivity matrices a2-5, [a(:,:,2-5)]

  
for m = 1 : Npc-2;       % Loop over elements 2-5, hydro-elastic
                    
     for i = 1 : ndofel; % Loop over the 12 DOF's of the elements
    
        apc(i , i+(6*m) , m+1) = 1;
    
        
     end
        
end

% The connectivity matrices are thus stored in a matrix array where the
% connectivity matrix linking the i'th element's DOF's to the DOF's of the
% sub-system is stored as apc(:,:,i).

end
