function [Mec] = Bergsoy_pc_connector_structural_mass_matrix(dens,Jc,Lc,Ac)
%
% Purpose:     Determination of a mass matrix for the pontoon connector as
%              a 3D beam element with twelve degrees of freedom
%              in a local element coordinate system.
%
%              The mass matrix terms for axial, torsional and bending about
%              the y- and z-axis displacements are added into the 12x12
%              element mass matrix according to the numbering of the
%              element DOF's.
%  
% Input:     dens  - density of element material
%              Jc  - torsional moment of inertia of the element
%              Lc  - length of the connector
%              Ac  - cross-sectional area
%
% Output:      Me - mass matix for the connector rod 
%
%

Le = Lc;      % Length of element

me = dens*Ac*Lc;

Mec = zeros(12);

Mec(1,1) = 140;
Mec(7,1) = 70; 

Mec(2,2)  = 156;
Mec(5,2)  = 22*Le;
Mec(8,2)  = 54;
Mec(11,2) = -13*Le;

Mec(3,3)  = 156;
Mec(6,3)  = 22*Le;
Mec(9,3)  = 54;
Mec(12,3) = -13*Le;

Mec(4,4)  = 140*Jc/Ac;
Mec(10,4) = 70*Jc/Ac;

Mec(5,5)  = 4*Le^2;
Mec(8,5)  = 13*Le;
Mec(11,5) = -3*Le^2;

Mec(6,6)  = 4*Le^2;
Mec(9,6)  = 13*Le;
Mec(12,6) = -3*Le^2;

Mec(7,7) = 140;

Mec(8,8)  = 156;
Mec(11,8) = -22*Le;

Mec(9,9) = 156;
Mec(12,9) = -22*Le;

Mec(10,10) = 140*Jc/Ac;
Mec(11,11) = 4*Le^2;
Mec(12,12) = 4*Le^2;

for i=1:12;
    for j=1:12;
        Mec(i,j)=Mec(j,i);
    end
end

Mec = Mec*me/420;

 end

