function [Kec] = Bergsoy_pc_connector_structural_stiffness_matrix(Es,nus,Lc,Ac,Iyc,Izc,Jc)
%
% Purpose:     Determination of a stiffness matrix for 
%              a 3D beam element with twelve degrees of freedom
%              in a local element coordinate system. The three dimensional
%              stiffness matrix is of dimension [12x12] as the 3D beam
%              element has a total of 12 DOF's.
%  
% Input:       Es  - Young's modulus steel
%              nus - Poisson's ratio steel
%              Lc  - length of the connector rod
%              Ac  - cross-sectional area of connector rod
%              Izc - moment of inertia of cross-section about z axis for
%                    the connector rod
%              Iyc - moment of inertia of cross-section about y axis for
%                    the connector rod
%              Jc  - polar moment of inertia for the connector rod
%
% Output:      Kec - stiffness matix for the connector rod
%
%

Le = Lc;       % Element length

G   = Es/(2*(1+nus));
Kec = zeros(12,12);
kt  = (Ac*Es/Le)*[1 -1;-1 1];
ktor = (Jc*G/Le)*[1 -1;-1 1];

kbeam = [  12/Le^3     6/Le^2    -12/Le^3    6/Le^2,
             6/Le^2     4/Le       -6/Le^2    2/Le     ,
          - 12/Le^3    -6/Le^2     12/Le^3   -6/Le^2  ,
             6/Le^2     2/Le       -6/Le^2    4/Le   ];
     

     
Kec([1 7],[1 7]) = kt;
Kec([4 10],[4 10]) = ktor;
Kec([2 5 8 11],[2 5 8 11]) = kbeam*Es*Izc;
Kec([3 6 9 12],[3 6 9 12]) = kbeam*Es*Iyc;


 end



