function [Mesup] = Bergsoy_sup_structural_mass_matrix(dens,Jsup,Le,Nsup,Asup)
%
% Purpose:     Determination of a mass matrix for the superstructure
%              elements as 3D beam elements with twelve degrees of freedom
%              in a local element coordinate system.
%
%              The mass matrix terms for axial, torsional and bending about
%              the y- and z-axis displacements are added into the 12x12
%              element mass matrix according to the numbering of the
%              element DOF's. A mass matrix is developed for each element
%              as their lenght vary some across the length of the bridge.
%              These matrices are stored in a matrix array.
%  
% Input:    dens  - density of element material,steel
%             Le  - vector with lengths of each member
%           Jsup  - torsional moment of inertia of the element
%             dx  - length of the member
%           Asup  - cross-sectional area
%
% Output:   Mesup - mass matrix array
%
%
% By Axel Wullf Wathne, 2012.
%


Mesup = zeros(12,12,(Nsup-1));  % Matrix array for the mass matrices of the elements
                                % making up the superstructure.

for i = 1:Nsup-1;               % Loop over each element in the superstructure



me(i) = dens*Asup*Le(i);


Mesup(1,1,i) = 140;
Mesup(7,1,i) = 70; 

Mesup(2,2,i)  = 156;
Mesup(5,2,i)  = 22*Le(i);
Mesup(8,2,i)  = 54;
Mesup(11,2,i) = -13*Le(i);

Mesup(3,3,i)  = 156;
Mesup(6,3,i)  = 22*Le(i);
Mesup(9,3,i)  = 54;
Mesup(12,3,i) = -13*Le(i);

Mesup(4,4,i)  = 140*Jsup/Asup;
Mesup(10,4,i) = 70*Jsup/Asup;

Mesup(5,5,i)  = 4*Le(i)^2;
Mesup(8,5,i)  = 13*Le(i);
Mesup(11,5,i) = -3*Le(i)^2;

Mesup(6,6,i)  = 4*Le(i)^2;
Mesup(9,6,i)  = 13*Le(i);
Mesup(12,6,i) = -3*Le(i)^2;

Mesup(7,7,i) = 140;

Mesup(8,8,i)  = 156;
Mesup(11,8,i) = -22*Le(i);

Mesup(9,9,i) = 156;
Mesup(12,9,i) = -22*Le(i);

Mesup(10,10,i) = 140*Jsup/Asup;
Mesup(11,11,i) = 4*Le(i)^2;
Mesup(12,12,i) = 4*Le(i)^2;

for j=1:12;
    for k=1:12;
        Mesup(j,k,i)=Mesup(k,j,i);
    end
end

Mesup(:,:,i) = Mesup(:,:,i)*me(i)/420;

end

end

