function [asup,ndofsup] = Bergsoy_superstructure_connectivity_matrices(Nsup)

%
% Function to establish the connectivity matrices linking the superstructure
% element DOF's to the DOF's of the superstructure sub-system.
%
% Each element has undergone a transformation prior to the introduction of
% the connectivity matrices. As a result, the property matrices of each
% element are related to the global coordinate system, which coincides with
% the coordinate system applied for the superstructure sub-system.
% Consequently, the DOF's of the elements have a one-to-one relation with
% the sub-system DOF's. This simplifies the connectivity matrices, but
% these are only valid as long as the mass and stiffness matrices they are
% applied to are already transformed from the local element axes to the
% global axes.
%
% Further, the connectivity matrices will be of dimension [12x150] due to
% 12DOF's of the 3D beam element, and 150DOF's of the superstructure
% sub-system.
%
% Input: Nsup - number of nodes along the bridge superstructure
%
%
% By Axel Wullf Wathne
%



% Number of DOF's for the bridge superstructure

ndofsup = Nsup*6;   % 6DOF's associated with each node for 3D-element
ndofel  = 12;       % 12DOF's associated with each element


% Matrix array of superstructure connectivity matrices

asup = zeros(ndofel,ndofsup,Nsup-1);

for m = 0:Nsup-2;     % Loop over all elements of the superstructure
    
    for i = 1:12;   % Loop over the element DOF's transformed into global coordinate system
    
    
    asup(i, i+(6*m) , m+1) = 1;
    
    end
    
end

% The connectivity matrices are now stored in a matrix array. The
% connectivity matrix linking the i'th element to the corresponding
% superstructure DOF's is found as asup(:,:,i).

end