clear all
clc


% Properties of the bridge superstructure sub-system, evaluated as an
% equivalent steel box cross-section.

L    =  840;      % length of bridge in x-direction  
B    = 11.2;      % width of superstructure
h    = 7.00;      % height of superstructure
tds  = 0.08;      % thickness of the top deck of the superstructure
ts   = 0.04;      % thickness of the bottom deck of the superstructure
tws  = 0.01;      % thickness of side walls of the superstructure
Nsup = 25;        % number of nodes along the superstructure  


% Properties of the PC-sub system

Lp = 30;        % length of pontoon
Bp = 20;        % width of pontoon in the fluid
hp = 7;         % height of pontoon
td = 0.35;      % thickness of pontoon top and bottom deck
tw = 0.55;      % thickness of pontoon walls
Awp= Lp*Bp;     % water plane area
dx = Lp/4;      % length of pontoon elements, 4.

Lc = 1.20;      % length of connector rod
ry = 1.00;      % outer radius of connector rod, assumed circular      
tc = 0.05;      % thickness of connector rod, assumed circular

Ap = 2*(Bp*td+(hp-(2*td))*tw);  % Area of pontoon cross-section, assumed hollow quadratic section
Ac = 4*pi*(2*ry*tc - tc^2);     % Area of four connector cross-section, assumed hollow circular section   

Asup = (2*(h-tds-ts)*tws)+(B*(tds+ts)); % Area of superstructre cross-section, assumed hollow quadratic section [m2]


denp = 2500;                    % Density of concrete
denS = 7500;                    % Density of steel


g    = 9.81;                    % Gravitational constant
rhow = 1025;                    % Density of salt water


% Evaluation of the draft of a pontoon

% It is assumed that the weight of the overlying structure is equally
% distributed across the pontoons. Such that the weigth on a single pontoon
% is equal to the weight of two superstructure elements, the connector rod
% element and the two pontoon elements.


Lesup = L/(Nsup-1);     % Approximate length of each superstructure element

W  = (3*(Lesup*Asup*denS) + (Lp*Ap*denp) + (Lc*Ac*denS))*g;  % Weight distributed to
                                                              % one pontoon from the
                                                              % above structure.

kB = rhow*g*Bp*Lp;       % Buoyancy stiffness 
                                                            
d  = W/kB;               % Draft of the pontoon  
