function [Sf] = JONSWAP_spectrum_Hz(Hs,Tp,w)


% JONSWAP wave spectrum in Hz
%
% A development of the JONSWAP spectrum in Hertz to be applied to the
% development of the directional response spectrum by combining with FRF's.
%
% 
%
% Input:  Hs - significant wave height
%         Tp - peak period
%     sigmaA - spectrum coefficient
%     sigmaB - spectrum coefficient
%      gamma - spectrum coefficient
%
% Output: Sf - Values of the JONSWAP spectrum for plotting
%
%
% By Axel Wullf Wathne, 2012
%



f=w./(2*pi);


% Definition of JONWAP spectrum parameters

sigmaA = 0.07;
sigmaB = 0.09;
gamma  = 1.00;


% Peak frequency of the sea state, in hertz.

fp = 1/Tp;


% Value vector for spectrum quantities

Sf = zeros (length(f) , 1);



for i = 1 : length(f);
    
    
   
% Function variable sigma

if f(i) <= fp
    
    sigma = sigmaA;
    
else        % implying f(i) > fp
    
    sigma = sigmaB;
    
end
    

% Function variable alpha

alpha = 0.0624 / ( 0.23 + 0.0336*gamma - 0.185*(1.9+gamma)^(-1));


% JONSWAP spectrum

Sf(i) = alpha*(Hs^2)*(fp^(-1))*((f(i)/fp)^(-5))*(exp(-1.25*((f(i)/fp)^(-4))))*gamma^(-(((f(i)/fp)-1)^2)/(2*sigma^2));



end

% figure(1)
% plot(f,Sf);
% title(['JONSWAP spectrum - Significant Wave Height Hs = ',num2str(Hs),'Peak period Tp = ',num2str(Tp),]);
% xlabel('Frequency, Hz');


end







